faceless-reels.core

Public product metadata and canonical URL helpers for Faceless Reels.

Public product metadata and canonical URL helpers for Faceless Reels.
raw docstring

homepageclj

The canonical Faceless Reels homepage.

The canonical Faceless Reels homepage.
raw docstring

productclj

Public product metadata suitable for catalog and integration UIs.

Public product metadata suitable for catalog and integration UIs.
raw docstring

public-routesclj

Stable public routes exposed by the Faceless Reels website.

Stable public routes exposed by the Faceless Reels website.
raw docstring

route-urlclj

(route-url route)

Returns the canonical absolute URL for a route keyword.

Throws when route is not present in public-routes.

Returns the canonical absolute URL for a route keyword.

Throws when `route` is not present in `public-routes`.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries