Public product metadata and canonical URL helpers for Faceless Reels.
Public product metadata and canonical URL helpers for Faceless Reels.
The canonical Faceless Reels homepage.
The canonical Faceless Reels homepage.
Public product metadata suitable for catalog and integration UIs.
Public product metadata suitable for catalog and integration UIs.
Stable public routes exposed by the Faceless Reels website.
Stable public routes exposed by the Faceless Reels website.
(route-url route)Returns the canonical absolute URL for a route keyword.
Throws when route is not present in public-routes.
Returns the canonical absolute URL for a route keyword. Throws when `route` is not present in `public-routes`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |